@@ -1,9 +1,9 @@
 import datetime
 import logging
 
-
 from lxml import html
 import simplejson
+import mock
 
 from . import details
 from . import essay
@@ -34,7 +34,7 @@ class Profile(object):
     properties if necessary.
     """
 
-    def __init__(self, session, username):
+    def __init__(self, session, username, **kwargs):
         """
         :param session: A logged in :class:`~okcupyd.session.Session`
         :param username: The username associated with the profile.
@@ -53,6 +53,19 @@ class Profile(object):
         #: user that this profile belongs to.
         self.details = details.Details(self)
 
+        if kwargs:
+            self._set_cached_properties(kwargs)
+
+    def _set_cached_properties(self, values):
+        property_names = set(
+            name for name, _ in util.cached_property.get_cached_properties(self)
+        )
+        for key, value in values.items():
+            if key not in property_names:
+                log.warning("Unrecognized kwarg {0} with value {1} "
+                            "passed to Profile constructor.")
+            self.__dict__[key] = value
+
     def refresh(self, reload=False):
         """
         :param reload: Make the request to return a new profile tree. This will
