@@ -6,6 +6,7 @@ import IPython
 from . import copy
 from . import db as db_collection
 from okcupyd import user, db, util
+from okcupyd.db import model
 
 
 log = logging.getLogger(__name__)
@@ -25,6 +26,12 @@ def interactive():
     u = user.User()
     IPython.embed()
 
+@ns.add_task
+@task(aliases='s')
+def session():
+    with db.txn() as session:
+        IPython.embed()
+
 
 @ns.add_task
 @task(login)
@@ -33,7 +40,7 @@ def enable_logger(logger_name):
 
 
 @ns.add_task
-@task(login, aliases=('c',))
+@task(aliases=('c',))
 def credentials(module_name):
     util.update_settings_with_module(module_name)
 
